@@ -1,14 +1,14 @@
 package Complete::TZ;
 
-our $DATE = '2015-09-18'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
-use Complete::Setting;
+use Complete::Common qw(:all);
 use Complete::Util qw(hashify_answer);
 
 require Exporter;
@@ -34,7 +34,7 @@ on systems that have that.
 
 _
     args => {
-        word => { schema=>'str', pos=>0 },
+        %arg_word,
     },
     result_naked => 1,
     result => {
@@ -77,7 +77,7 @@ Complete::TZ - Timezone-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.06 of Complete::TZ (from Perl distribution Complete-TZ), released on 2015-09-18.
+This document describes version 0.07 of Complete::TZ (from Perl distribution Complete-TZ), released on 2015-11-29.
 
 =head1 DESCRIPTION
 
@@ -91,11 +91,15 @@ Complete from list of timezone names.
 Currently implemented via looking at C</usr/share/zoneinfo>, so this only works
 on systems that have that.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<word> => I<str>
+=item * B<word>* => I<str> (default: "")
+
+Word to complete.
 
 =back
 
